@@ -12,7 +12,7 @@ from peewee_aio.manager import Manager, cached_property
 from .fields import JSONField, Choices
 
 
-__version__ = "0.2.2"
+__version__ = "0.2.3"
 __project__ = "muffin-peewee-aio"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "MIT"
@@ -80,7 +80,7 @@ class Plugin(BasePlugin):
                 :param auto: Track changes and setup migrations automatically
                 """
                 with manager.allow_sync():
-                    router.create(name, auto and [m for m in self.models.values()])
+                    router.create(name, auto and [m for m in self.models])
 
             @app.manage
             def pw_rollback(name: str = None):
